@@ -182,7 +182,8 @@ gboolean fm_launch_files(GAppLaunchContext* ctx, GList* file_infos, FmFileLaunch
         if (!fm_file_info_is_symlink(fi))
             /* symlinks also has fi->target, but we only handle shortcuts here. */
             target = fm_file_info_get_target(fi);
-        if (launcher->open_folder && fm_file_info_is_dir(fi))
+        if (launcher->open_folder &&
+            (fm_file_info_is_dir(fi) || fm_file_info_is_mountable(fi)))
         {
             /* special handling for shortcuts */
             if(target)
@@ -398,7 +399,9 @@ _launch_desktop_entry:
                 g_list_foreach(fis, (GFunc)g_free, NULL);
                 g_object_unref(app);
             }
-            else if (launcher->error)
+            else if (launcher->error && !launcher->get_app)
+                /* SF#837: don't show an error window after user pressed
+                   'Cancel' in the selection window, it'll annoy user */
                 g_set_error(&err, G_IO_ERROR, G_IO_ERROR_FAILED,
                             _("No default application is set for MIME type %s"),
                             type);
