@@ -341,6 +341,7 @@ static gboolean is_thumbnail_outdated(GObject* thumb_pix, const char* thumbnail_
     char* thumb_mtime = backend.get_image_text(thumb_pix, "tEXt::Thumb::MTime");
     gboolean outdated = FALSE;
     /* FIXME: compare thumbnail URI with value from tEXt::Thumb::URI */
+    /* g_print("thumb_mtime: %s, %ld\n", thumb_mtime, mtime); */
     if(thumb_mtime)
     {
         if(atol(thumb_mtime) != mtime)
@@ -437,8 +438,13 @@ static gpointer load_thumbnail_thread(gpointer user_data)
     gchar* large_basename = strrchr(large_path, '/') + 1;
 
     /* ensure thumbnail directories exists */
+    *(normal_basename - 1) = '\0';
     g_mkdir_with_parents(normal_path, 0700);
+    *(normal_basename - 1) = '/';
+
+    *(large_basename - 1) = '\0';
     g_mkdir_with_parents(large_path, 0700);
+    *(large_basename - 1) = '/';
 
     for(;;)
     {
@@ -889,10 +895,29 @@ static gboolean generate_thumbnails_with_builtin(ThumbnailTask* task)
     if(ins)
     {
         GObject* ori_pix = NULL;
+#ifdef USE_EXIF
+        FmMimeType* mime_type;
+#endif
         int rotate_degrees = 0;
+        goffset file_size;
+
+        if(fm_file_info_is_symlink(task->fi))
+        {
+            /* if the image file is a symlink, get the real size of its target */
+            GFileInfo* info = g_file_query_info(gf, G_FILE_ATTRIBUTE_STANDARD_SIZE, G_FILE_QUERY_INFO_NONE, cancellable, NULL);
+            if(info)
+            {
+                file_size = g_file_info_get_size(info);
+                g_object_unref(info);
+            }
+            else
+                file_size = 0;
+        }
+        else
+            file_size = fm_file_info_get_size(task->fi);
 #ifdef USE_EXIF
         /* use libexif to extract thumbnails embedded in jpeg files */
-        FmMimeType* mime_type = fm_file_info_get_mime_type(task->fi);
+        mime_type = fm_file_info_get_mime_type(task->fi);
         if(strcmp(fm_mime_type_get_type(mime_type), "image/jpeg") == 0) /* if this is a jpeg file */
         {
             /* try to extract thumbnails embedded in jpeg files */
@@ -966,10 +991,10 @@ static gboolean generate_thumbnails_with_builtin(ThumbnailTask* task)
                 g_object_unref(ins);
                 ins = g_file_read(gf, cancellable, NULL);
             }
-            ori_pix = backend.read_image_from_stream(G_INPUT_STREAM(ins), fm_file_info_get_size(task->fi), cancellable);
+            ori_pix = backend.read_image_from_stream(G_INPUT_STREAM(ins), file_size, cancellable);
         }
 #else
-        ori_pix = backend.read_image_from_stream(G_INPUT_STREAM(ins), fm_file_info_get_size(task->fi), cancellable);
+        ori_pix = backend.read_image_from_stream(G_INPUT_STREAM(ins), file_size, cancellable);
 #endif
         g_input_stream_close(G_INPUT_STREAM(ins), NULL, NULL);
         g_object_unref(ins);
@@ -1149,8 +1174,6 @@ static void generate_thumbnails_with_thumbnailers(ThumbnailTask* task)
                 {
                     generated |= GENERATE_NORMAL;
                     normal_pix = backend.read_image_from_file(task->normal_path);
-                    if (normal_pix)
-                        save_thumbnail_to_disk(task, normal_pix, task->normal_path);
                 }
             }
             if((task->flags & GENERATE_LARGE) && !(generated & GENERATE_LARGE))
@@ -1159,8 +1182,6 @@ static void generate_thumbnails_with_thumbnailers(ThumbnailTask* task)
                 {
                     generated |= GENERATE_LARGE;
                     large_pix = backend.read_image_from_file(task->large_path);
-                    if (large_pix)
-                        save_thumbnail_to_disk(task, large_pix, task->large_path);
                 }
             }
 
